package cn.com.infosec.asn1.ocsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.X509Extensions;

public class ResponseData extends ASN1Encodable {
   private static final DERInteger V1 = new DERInteger(0);
   private boolean versionPresent;
   private DERInteger version;
   private ResponderID responderID;
   private DERGeneralizedTime producedAt;
   private ASN1Sequence responses;
   private X509Extensions responseExtensions;

   public ResponseData(DERInteger version, ResponderID responderID, DERGeneralizedTime producedAt, ASN1Sequence responses, X509Extensions responseExtensions) {
      this.version = version;
      this.responderID = responderID;
      this.producedAt = producedAt;
      this.responses = responses;
      this.responseExtensions = responseExtensions;
   }

   public ResponseData(ResponderID responderID, DERGeneralizedTime producedAt, ASN1Sequence responses, X509Extensions responseExtensions) {
      this(V1, responderID, producedAt, responses, responseExtensions);
   }

   public ResponseData(ASN1Sequence seq) {
      int var2 = 0;
      if (seq.getObjectAt(0) instanceof ASN1TaggedObject) {
         if (((ASN1TaggedObject)seq.getObjectAt(0)).getTagNo() == 0) {
            this.versionPresent = true;
            this.version = DERInteger.getInstance((ASN1TaggedObject)seq.getObjectAt(0), true);
            var2 = 1;
         } else {
            this.version = V1;
         }
      } else {
         this.version = V1;
      }

      this.responderID = ResponderID.getInstance(seq.getObjectAt(var2++));
      this.producedAt = (DERGeneralizedTime)seq.getObjectAt(var2++);
      this.responses = (ASN1Sequence)seq.getObjectAt(var2++);
      if (seq.size() > var2) {
         this.responseExtensions = X509Extensions.getInstance((ASN1TaggedObject)seq.getObjectAt(var2), true);
      }

   }

   public static ResponseData getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static ResponseData getInstance(Object obj) {
      if (obj != null && !(obj instanceof ResponseData)) {
         if (obj instanceof ASN1Sequence) {
            return new ResponseData((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (ResponseData)obj;
      }
   }

   public DERInteger getVersion() {
      return this.version;
   }

   public ResponderID getResponderID() {
      return this.responderID;
   }

   public DERGeneralizedTime getProducedAt() {
      return this.producedAt;
   }

   public ASN1Sequence getResponses() {
      return this.responses;
   }

   public X509Extensions getResponseExtensions() {
      return this.responseExtensions;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      DERTaggedObject var2;
      if (this.versionPresent || !this.version.equals(V1)) {
         DERTaggedObject var10001 = var2 = new DERTaggedObject;
         DERInteger var3 = this.version;
         var10001.<init>(true, 0, var3);
         var1.add(var2);
      }

      var1.add(this.responderID);
      var1.add(this.producedAt);
      var1.add(this.responses);
      X509Extensions var4;
      if ((var4 = this.responseExtensions) != null) {
         var2 = new DERTaggedObject.<init>(true, 1, var4);
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
